#!/usr/bin/env python

import pygtk
pygtk.require ("2.0")
import gtk
import gtk.glade
import gtkmozembed

APPNAME = "My Browser"
VERSION = "0.1"
IMG_START = "img_start.gif"
IMG_STOP = "img_stop.png"


class Browser:
	def __init__(self):
		glade_file = gtk.glade.XML ("browser.glade", None, None)
		self.window = glade_file.get_widget ("window")
		self.vbox_browser = glade_file.get_widget ("vbox_browser")
		self.entry_url = glade_file.get_widget ("entry_url")
		self.button_back = glade_file.get_widget ("button_back")
		self.button_forward = glade_file.get_widget ("button_forward")
		self.button_stop = glade_file.get_widget ("button_stop")
		self.button_go = glade_file.get_widget ("button_go")
		self.image = glade_file.get_widget ("image")
		
		self.browser = gtkmozembed.MozEmbed()
		self.browser.load_url("about:blank")
		self.vbox_browser.pack_start (self.browser)

		# set some values
		self.window.set_title (APPNAME)
	
		# show widget
		self.browser.show()
		self.window.show_all()

		# signals
		self.window.connect ("delete_event", self.on_delete_event)
		self.entry_url.connect ("key_press_event",self.on_key_press)

		self.browser.connect ("net_start", self.on_net_start)
		self.browser.connect ("net_stop", self.on_net_stop)
		self.browser.connect ("progress", self.on_progress)

		self.button_back.connect ("clicked", self.on_button_back_clicked)
		self.button_forward.connect ("clicked", self.on_button_forward_clicked)
		self.button_stop.connect ("clicked", self.on_button_stop_clicked)
		self.button_go.connect ("clicked", self.on_entry_changed)
	
	def main(self):
		gtk.main()
	
	def on_delete_event (self, widget, event, user_data = None):
		gtk.main_quit ()
	
	def on_key_press (self, widget, event, user_data = None):
		if event.keyval == gtk.keysyms.Return:
			 self.on_entry_changed ()
	
	def on_entry_changed (self, data = None):
		self.browser.load_url(self.entry_url.get_text())

	def on_net_start (self, data = None):
		self.button_stop.set_sensitive (True)
		self.image.set_from_file (IMG_START)

	def on_net_stop (self, data = None):
		self.button_stop.set_sensitive (False)
		self.button_back.set_sensitive (self.browser.can_go_back())
		self.button_forward.set_sensitive (self.browser.can_go_forward())
		self.image.set_from_file (IMG_STOP)

	def on_button_back_clicked (self, data = None):
		self.browser.go_back()

	def on_button_forward_clicked (self, data = None):
		self.browser.go_forward()

	def on_button_stop_clicked (self, data = None):
		self.browser.stop_load()
	
	def on_progress (self, moz, current, max, data = None):
		title = self.browser.get_title ()

		if len (title) > 0:
			self.window.set_title (APPNAME + " - " + title)
		else:
			self.window.set_title (APPNAME)
	


if __name__ == "__main__":

	browser = Browser ()
	browser.main()
